logopt

package
v0.0.0-...-18194de Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Data

type Data struct {
	ErrType    int
	NoFuncName bool
	NoLoc      bool
	IsInternal bool // marks error as originating from internal (non-userspace) code
	LocNewLine bool // put PHP location on a new line (for messages with embedded location)
	Loc        any  // optional *phpv.Loc override for error location
}

type ErrType

type ErrType int

type IsInternal

type IsInternal bool

type LocNewLine

type LocNewLine bool

LocNewLine causes the " in FILE on line N" location suffix to be output on a new line with a leading space, instead of appended to the same line. Used for messages that already contain their own "in X on line N" info (e.g. INI parser errors).

type NoFuncName

type NoFuncName bool

type NoLoc

type NoLoc bool

Jump to