Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IsInternal ¶
type IsInternal bool
type LocNewLine ¶
type LocNewLine bool
LocNewLine causes the " in FILE on line N" location suffix to be output on a new line with a leading space, instead of appended to the same line. Used for messages that already contain their own "in X on line N" info (e.g. INI parser errors).
type NoFuncName ¶
type NoFuncName bool
Click to show internal directories.
Click to hide internal directories.